@@ -66,6 +66,9 @@ function(x=NULL,
     x <- as.matrix(x)
   } else x <- numeric(0)
 
+  if(orderBy == "timeDate" && missing(tzone)) {
+    tzone <- order.by@FinCenter
+  } else
   if(!is.null(attr(order.by,"tzone")) && missing(tzone))
     tzone <- attr(order.by, "tzone")
   if(inherits(order.by,'dates'))
